@@ -7,12 +7,12 @@ from django.conf.urls.defaults import *
 urlpatterns = patterns('',
     # Example:
     # (r'^frontwebproject/', include('frontwebproject.foo.urls')),
-
     # Uncomment the admin/doc line below to enable admin documentation:
     # (r'^admin/doc/', include('django.contrib.admindocs.urls')),
-
     # Uncomment the next line to enable the admin:
     # (r'^admin/', include(admin.site.urls)),
-    (r"^plugins", 'frontweb.views.list_plugins'),
-    (r"^(.*)$", 'frontweb.views.query_file'),
+    # Descomentar y comentar la anterior para deshabilitar todos los plugins:
+    # ("^(.*)$", 'frontweb.views.query_file'),
+
+    (r'', include("frontweb.urls"),),
 )
